import { Metadata, Http } from '@zeedhi/core';
import {
  AlertService, Form, Modal, ModalService,
} from '@zeedhi/common';
import { FileUpload } from '@/services/FileUpload';

export class ImportacaoAFController {
  public accept: string = '.txt';
  
  public dense: boolean = true;
  
  public showSize: boolean = true;
  
  public showHelper: boolean = true;
  
  public showLabel: boolean = true;
  
  public removableChip: boolean = true;
  
  public truncateLength: string = '22';

  private modalErrosImportacao!: Modal;
 
  public async importAF() {
    const form = Metadata.getInstance<Form>('formImportacaoAfTxt');
    const valid = form.validate();
    const fieldCDFILIAL = Metadata.getInstance<any>('CDFILIAL');
    const fieldFILE: any = Metadata.getInstance('arquivo');

    if (!valid) {
      AlertService.show({
        top: true,
        right: true,
        timeout: 2000,
        name: 'formInvalidoAlert',
        text: 'Preencha todos os campos obrigatórios!',
        color: 'error',
      });
    } else {
      const fieldFileValue = await FileUpload.getFileContent(fieldFILE.value);
      const arrayData = {
        CDFILIAL: fieldCDFILIAL.value != null ? fieldCDFILIAL.value.CDFILIAL : null,
        FILE: fieldFileValue,
      };
      
      const content = fieldFileValue.content[0];
      const itens = content.ITENS[0];
      const cdFilialDest = itens.CDFILDEST;
      
      if (arrayData.CDFILIAL !== cdFilialDest) {
        AlertService.show({
          top: true,
          right: true,
          timeout: 2000,
          name: 'failedOperation',
          text: 'Filial do arquivo diferente da Filial selecionada!',
          color: 'error',
        });
      } else {
        form.submit();
        await Http.post('/inclusaoImportacaoAfTxt', {
          requestType: 'DataSet',
          dataset: [
            {
              ARRAY_DATA:
              [
                arrayData,
              ],
            },
          ],
        }).then((response) => {
          if (response.data.dataset.data[0] === 'error') {
            this.openModalErrosImportacao(response.data.dataset.data[1]);
          } else if (response.data.dataset.data[0] === 'success') {
            AlertService.show({
              top: true,
              right: true,
              timeout: 2000,
              name: 'successOperation',
              text: 'Operação realizada com sucesso!',
              color: 'success',
            });
            fieldCDFILIAL.value = '';
            fieldFILE.value = '';
          } else {
            AlertService.show({
              top: true,
              right: true,
              timeout: 2000,
              name: 'failedOperation',
              text: 'Falha na execução da operação!',
              color: 'error',
            });
          }
        });
      }
    }
  }

  public async openModalErrosImportacao(erros:any[]) {
    if (!this.modalErrosImportacao) {
      this.modalErrosImportacao = ModalService.create({
        name: 'modalErrosImportacao',
        fullscreen: false,
        virtualScroll: false,
        children: [
          {
            name: 'headerContainer',
            component: 'ZdContainer',
            children: [
              {
                name: 'headerFixed',
                component: 'ZdHeader',
                color: 'transparent',
                padless: true,
                elevation: 0,
                centerSlot: [
                  {
                    name: 'titleText',
                    component: 'ZdText',
                    text: 'Erros na Importação de AF',
                    cssClass: 'zd-theme-font-title',
                  },
                ],
                rightSlot: [
                  {
                    name: 'closeModalButton',
                    component: 'ZdModalCloseButton',
                    small: true,
                    modalName: 'modalErrosImportacao',
                  },
                ],
              },
              {
                name: 'general-grid',
                component: 'ZdGrid',
                gridHeight: '420px',
                virtualScroll: true,
                dense: 'false',
                showFooter: 'true',
                showHeader: 'true',
                columns: [
                  {
                    name: 'NRLINHA',
                    label: 'Linha',
                    sortable: false,
                  },
                  {
                    name: 'POSICAO',
                    label: 'Item Posição',
                    maxWidth: '100px',
                  },
                  {
                    name: 'TAMANHO',
                    label: 'Tamanho',
                    maxWidth: '75px',
                  },
                  {
                    name: 'VALOR',
                    label: 'Valor',
                    maxWidth: '170px',
                    overflow: 'wrap',
                  },
                  {
                    name: 'MENSERRO',
                    label: 'Descrição do Erro',
                    overflow: 'wrap',
                  },
                ],
                datasource: {
                  data: erros,
                  limit: 10,
                  lazyLoad: false,
                },
              },
            ],
          },
        ],
      });
    }

    this.modalErrosImportacao.show();
  }

  public closeModal() {
    this.modalErrosImportacao.hide();
  }
}
